==> rospell-2006.01.tar.gz: rospell-2006.01/src/rospell/briefedit.h <==
//****************************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//****************************************************************************

#ifndef BRIEFEDIT_H
#define BRIEFEDIT_H
#include "editor.h"


#ifdef USING_QT3
#include <qmultilineedit.h>
#endif
#ifdef USING_QT4
#include <q3multilineedit.h>
#endif

#include <qevent.h>

#include "debug.h"
#include "global.h"
#include <stdio.h>


class BriefEdit: public Q3MultiLineEdit {
public:
	BriefEdit(QWidget * parent = 0, const char * name = 0);
	virtual ~BriefEdit() {}
	bool recordAction();
	void playbackAction();
	volatile int isRecording() {
		return recording_;
	}
	void reloadAlias();

protected:
	void selectLine(int para, int index);
	void keyPressEvent(QKeyEvent *e);

private:
	bool normal_insert_;
	volatile int recording_;
	list<QKeyEvent> list_;
	QString alias_buf_;
	list<Global::Alias> alist_;
};
	

#endif // BRIEFEDIT_H

==> rospell-2007.01.rc3.tar.gz: rospell-2007.01.rc3/src/rospell/briefedit.h <==
//****************************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//****************************************************************************

#ifndef BRIEFEDIT_H
#define BRIEFEDIT_H
#include "global.h"


#ifdef USING_QT3
#include <qmultilineedit.h>
#endif
#ifdef USING_QT4
#include <q3multilineedit.h>
#endif

#include <qevent.h>
#include <qpopupmenu.h>

class Editor;

class BriefEdit: public Q3MultiLineEdit {
	Q_OBJECT
public:
	BriefEdit(Editor *editor, QWidget * parent = 0, const char * name = 0);
	virtual ~BriefEdit() {}
	bool recordAction();
	void playbackAction();
	volatile int isRecording() {
		return recording_;
	}
	void reloadAlias();

public slots:
	void quickSearchClicked(int id);
	void shiftLeftClicked(int id);
	void shiftRightClicked(int id);
	void space2tabClicked(int id);
	void tab2spaceClicked(int id);

protected:
	void selectLine(int para, int index);
	void keyPressEvent(QKeyEvent *e);
	QPopupMenu *createPopupMenu(const QPoint& pos);	

private:
	bool normal_insert_;
	volatile int recording_;
	list<QKeyEvent> list_;
	QString alias_buf_;
	list<Global::Alias> alist_;
	Editor *editor_;
};
	

#endif // BRIEFEDIT_H
